% EXAMPLE_EllipsoidTri_MtBaker.m

clear all , close all


%% Approach

%  Normals point outward from ellipsoid surface
%  Thus a positive normal displacement (displacement in the same direction as the
%  normal) corresponds to a positive pressure and expansion of the elastic
%  body.
%  Modeling magma chamber as a displacement boundary from Hodge and Crider,
%  2010.
%
%  Model best fit to geodetic data is located 1360m north and 285m east of Mt
%  Baker summit at a depth of 5800m.
%  The best-fit volume change is -11e6 m^3  in elastic half space with Shear modulus
%  of 30GPa(E) and Poisson's ratio of 0.25. use sphere with volume change
%  volume and collapse to zero, or radius = (V(3/4pi))^(1/3) = 137.96 m and
%  normal burgers vector equal to the radus.
%  Proposed Poly3D BC on the elements are: 
%   Bd = Bx = 0; Bs = By = 0; Tn = -.42*E


%% Example
% Assume distances given in meters
% position of ellipsoid
xc = 587395.244645; yc = 5404666.07306; zc = -5800;
% trend (azimuth) and plunge (positive down) of ellipsoid; gamma is the
% ortation about the semi-major axis to allow rotation of the 
% semi-intermediate and semi-minor axes out of horizontal and vertical
% respectively
trend = 0; plunge = 90; gamma = 0;
% Define anisotropy through the semi-axial lengths
% r = (11e6*(3/4)/pi)^(1/3);
r = 1000;
xr = r; yr = r; zr = r;
% number of vertices definine the ellipsoid will be (n+1)^2
n = 10;

% Generate Ellipoid (default outward pointing normals)
[tri,v,nvec,tc,A] = EllipsoidTri(xc,yc,zc,xr,yr,zr,n,trend,plunge,gamma);
c = ones(length(tri),1);c(:,2:3) = zeros(length(tri),2);
% Visualize Resulting plot
figure
    h = trisurf(tri,v(:,1),v(:,2),v(:,3),ones(length(tri),1)); hold on
    set(h,'FaceAlpha',0.6,'LineWidth',0.1,'EdgeAlpha',0.7)
    quiver3(tc(:,1),tc(:,2),tc(:,3),nvec(:,1),nvec(:,2),nvec(:,3),'g','LineWidth',0.5)
    axis equal, box on, grid on
    d=[1 0 0];colormap(d)
    %colorbar
    hold on
    ha(1) = plot3([xc A.A1(1)],[yc A.A1(2)],[zc A.A1(3)],'r-','LineWidth',2);
    ha(2) = plot3([xc A.A2(1)],[yc A.A2(2)],[zc A.A2(3)],'k-','LineWidth',2);
    ha(3) = plot3([xc A.A3(1)],[yc A.A3(2)],[zc A.A3(3)],'b-','LineWidth',2);
    MyFormat = {'FontSize',14,'FontWeight','bold'};
    xlabel('x(m)',MyFormat{:}), 
    ylabel('y(m)',MyFormat{:}), 
    zlabel('z(m)',MyFormat{:})
    title('Triangulated Ellipsoid Surface',MyFormat{:})
%     legend(ha,'Semi-Major axis',...
%         'Semi-Intermediate axis',...
%         'Semi-Minor axis',...
%         'Location','NorthWest')
    
    

